====================
BG Review File Utils
====================

Collection of Python modules for reading and writing tab-delimited review files.



Features
--------

* ReviewParser class for reading tab-delimited review files
* ReviewWriter class for writing tab-delimited review files
* ReviewRecord class for representing review records

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
